@@ -13,7 +13,7 @@ import (
 func TestViewSettingsLoad(t *testing.T) {
 	cfg := config.NewCustomView()
 
-	assert.Nil(t, cfg.Load("testdata/view_settings.yaml"))
-	assert.Equal(t, 1, len(cfg.K9s.Views))
-	assert.Equal(t, 4, len(cfg.K9s.Views["v1/pods"].Columns))
+	assert.Nil(t, cfg.Load("testdata/views/views.yaml"))
+	assert.Equal(t, 1, len(cfg.Views))
+	assert.Equal(t, 4, len(cfg.Views["v1/pods"].Columns))
 }
