@@ -9,22 +9,11 @@ import (
 
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/model"
-	"github.com/derailed/k9s/internal/render"
+	"github.com/derailed/k9s/internal/model1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
-type (
-	// SortFn represent a function that can sort columnar data.
-	SortFn func(rows render.Rows, sortCol SortColumn)
-
-	// SortColumn represents a sortable column.
-	SortColumn struct {
-		name string
-		asc  bool
-	}
-)
-
 // Namespaceable represents a namespaceable model.
 type Namespaceable interface {
 	// ClusterWide returns true if the model represents resource in all namespaces.
@@ -63,11 +52,11 @@ type Tabular interface {
 	// Empty returns true if model has no data.
 	Empty() bool
 
-	// Count returns the model data count.
-	Count() int
+	// RowCount returns the model data count.
+	RowCount() int
 
 	// Peek returns current model data.
-	Peek() *render.TableData
+	Peek() *model1.TableData
 
 	// Watch watches a given resource for changes.
 	Watch(context.Context) error
