@@ -23,7 +23,7 @@ type Picker struct {
 func NewPicker() *Picker {
 	return &Picker{
 		List:    tview.NewList(),
-		actions: ui.KeyActions{},
+		actions: *ui.NewKeyActions(),
 	}
 }
 
@@ -38,7 +38,7 @@ func (p *Picker) Init(ctx context.Context) error {
 	}
 
 	pickerView := app.Styles.Views().Picker
-	p.actions[tcell.KeyEscape] = ui.NewKeyAction("Back", app.PrevCmd, true)
+	p.actions.Add(tcell.KeyEscape, ui.NewKeyAction("Back", app.PrevCmd, true))
 
 	p.SetBorder(true)
 	p.SetMainTextColor(pickerView.MainColor.Color())
@@ -48,7 +48,7 @@ func (p *Picker) Init(ctx context.Context) error {
 	p.SetTitle(" [aqua::b]Containers Picker ")
 
 	p.SetInputCapture(func(evt *tcell.EventKey) *tcell.EventKey {
-		if a, ok := p.actions[evt.Key()]; ok {
+		if a, ok := p.actions.Get(evt.Key()); ok {
 			a.Action(evt)
 			evt = nil
 		}
